@@ -23,8 +23,9 @@
 
 /*
 ** Build a string that contains all of the command-line options
-** specified as arguments.  If the option name begins with "+" then
-** it takes an argument.  Without the "+" it does not.
+** specified as arguments.  collect_argument() is used for stand-alone
+** options and collect_argument_value() is used for options that are
+** followed by an argument value.
 */
 static void collect_argument(Blob *pExtra,const char *zArg,const char *zShort){
   const char *z = find_option(zArg, zShort, 0);
@@ -71,13 +72,13 @@ static void collect_argv(Blob *pExtra, int iStart){
 **                pages.  Any additional arguments are passed on verbatim
 **                to the cache command.
 **
-**    changes     Shows all local checkouts that have uncommitted changes.
+**    changes     Shows all local check-outs that have uncommitted changes.
 **                This operation has no additional options.
 **
-**    clean       Delete all "extra" files in all local checkouts.  Extreme
+**    clean       Delete all "extra" files in all local check-outs.  Extreme
 **                caution should be exercised with this command because its
 **                effects cannot be undone.  Use of the --dry-run option to
-**                carefully review the local checkouts to be operated upon
+**                carefully review the local check-outs to be operated upon
 **                and the --whatif option to carefully review the files to
 **                be deleted beforehand is highly recommended.  The command
 **                line options supported by the clean command itself, if any
@@ -87,7 +88,7 @@ static void collect_argv(Blob *pExtra, int iStart){
 **
 **    dbstat      Run the "dbstat" command on all repositories.
 **
-**    extras      Shows "extra" files from all local checkouts.  The command
+**    extras      Shows "extra" files from all local check-outs.  The command
 **                line options supported by the extra command itself, if any
 **                are present, are passed along verbatim.
 **
@@ -110,6 +111,8 @@ static void collect_argv(Blob *pExtra, int iStart){
 **                present, are passed along verbatim.  The --force and
 **                --randomize options are not supported.
 **
+**    repack      Look for extra compression in all repositories.
+**
 **    sync        Run a "sync" on all repositories.  Only the --verbose
 **                and --unversioned and --share-links options are supported.
 **
@@ -139,10 +142,10 @@ static void collect_argv(Blob *pExtra, int iStart){
 **    ignore      Arguments are repositories that should be ignored by
 **                subsequent clean, extras, list, pull, push, rebuild, and
 **                sync operations.  The -c|--ckout option causes the listed
-**                local checkouts to be ignored instead.
+**                local check-outs to be ignored instead.
 **
 **    list | ls   Display the location of all repositories.  The -c|--ckout
-**                option causes all local checkouts to be listed instead.
+**                option causes all local check-outs to be listed instead.
 **
 ** Repositories are automatically added to the set of known repositories
 ** when one of the following commands are run against the repository:
@@ -150,9 +153,9 @@ static void collect_argv(Blob *pExtra, int iStart){
 ** are added back to the list of repositories by these commands.
 **
 ** Options:
-**   --dry-run         If given, display instead of run actions.
-**   --showfile        Show the repository or checkout being operated upon.
-**   --stop-on-error   Halt immediately if any subprocess fails.
+**   --dry-run         If given, display instead of run actions
+**   --showfile        Show the repository or check-out being operated upon
+**   --stop-on-error   Halt immediately if any subprocess fails
 */
 void all_cmd(void){
   Stmt q;
@@ -283,6 +286,27 @@ void all_cmd(void){
     collect_argument(&extra, "index",0);
     collect_argument(&extra, "noindex",0);
     collect_argument(&extra, "ifneeded", 0);
+  }else if( fossil_strcmp(zCmd, "remote")==0 ){
+    showLabel = 1;
+    quiet = 1;
+    collect_argument(&extra, "show-passwords", 0);
+    if( g.argc==3 ){
+      zCmd = "remote -R";
+    }else if( g.argc!=4 ){
+      usage("remote ?config-data|list|ls?");
+    }else if( fossil_strcmp(g.argv[3],"ls")==0
+           || fossil_strcmp(g.argv[3],"list")==0 ){
+      zCmd = "remote ls -R";
+    }else if( fossil_strcmp(g.argv[3],"ls")==0
+           || fossil_strcmp(g.argv[3],"list")==0 ){
+      zCmd = "remote ls -R";
+    }else if( fossil_strcmp(g.argv[3],"config-data")==0 ){
+      zCmd = "remote config-data -R";
+    }else{
+      usage("remote ?config-data|list|ls?");
+    }
+  }else if( fossil_strcmp(zCmd, "repack")==0 ){
+    zCmd = "repack";
   }else if( fossil_strcmp(zCmd, "setting")==0 ){
     zCmd = "setting -R";
     collect_argv(&extra, 3);
@@ -297,6 +321,7 @@ void all_cmd(void){
     collect_argument(&extra, "share-links",0);
     collect_argument(&extra, "verbose","v");
     collect_argument(&extra, "unversioned","u");
+    collect_argument(&extra, "all",0);
   }else if( fossil_strcmp(zCmd, "test-integrity")==0 ){
     collect_argument(&extra, "db-only", "d");
     collect_argument(&extra, "parse", 0);
@@ -385,8 +410,9 @@ void all_cmd(void){
     collect_argv(&extra, 3);
   }else{
     fossil_fatal("\"all\" subcommand should be one of: "
-                 "add cache changes clean dbstat extras fts-config git ignore "
-                 "info list ls pull push rebuild server setting sync ui unset");
+      "add cache changes clean dbstat extras fts-config git ignore "
+      "info list ls pull push rebuild remote "
+      "server setting sync ui unset");
   }
   verify_all_options();
   db_multi_exec("CREATE TEMP TABLE repolist(name,tag);");
@@ -427,7 +453,7 @@ void all_cmd(void){
       fossil_print("%s\n", zFilename);
       continue;
     }else if( showFile ){
-      fossil_print("%s: %s\n", useCheckouts ? "checkout" : "repository",
+      fossil_print("%s: %s\n", useCheckouts ? "check-out" : "repository",
                    zFilename);
     }
     zSyscmd = mprintf("%$ %s %$%s",
