@@ -55,6 +55,34 @@ struct Blob {
 */
 #define blob_buffer(X)  ((X)->aData)
 
+/*
+** Number of elements that fits into the current blob's size
+*/
+#define blob_count(X,elType)  (blob_size(X)/sizeof(elType))
+
+/*
+** Append blob contents to another
+*/
+#define blob_appendb(dest, src) \
+  blob_append((dest), blob_buffer(src), blob_size(src))
+
+/*
+** Append a string literal to a blob
+** TODO: Consider renaming to blob_appendl()
+*/
+#define blob_append_literal(blob, literal) \
+  blob_append((blob), "" literal, (sizeof literal)-1)
+  /*
+   * The empty string in the second argument leads to a syntax error
+   * when the macro is not used with a string literal. Unfortunately
+   * the error is not overly explicit.
+   */
+
+/*
+** TODO: Suggested for removal because the name seems misleading.
+*/
+#define blob_append_string blob_append_literal
+
 /*
 ** Seek whence parameter values
 */
@@ -98,6 +126,7 @@ int fossil_isspace(char c){
 int fossil_islower(char c){ return c>='a' && c<='z'; }
 int fossil_isupper(char c){ return c>='A' && c<='Z'; }
 int fossil_isdigit(char c){ return c>='0' && c<='9'; }
+int fossil_isxdigit(char c){ return (c>='0' && c<='9') || (c>='a' && c<='f'); }
 int fossil_tolower(char c){
   return fossil_isupper(c) ? c - 'A' + 'a' : c;
 }
@@ -327,13 +356,6 @@ void blob_append(Blob *pBlob, const char *aData, int nData){
   memcpy(&pBlob->aData[nUsed], aData, nData);
 }
 
-/*
-** Append a string literal to a blob.
-*/
-#if INTERFACE
-#define blob_append_string(BLOB,STR) blob_append(BLOB,STR,sizeof(STR)-1)
-#endif
-
 /*
 ** Append a single character to the blob.  If pBlob is zero then the
 ** character is written directly to stdout.
@@ -505,7 +527,7 @@ char *blob_terminate(Blob *p){
 ** Compare two blobs.  Return negative, zero, or positive if the first
 ** blob is less then, equal to, or greater than the second.
 */
-int blob_compare(Blob *pA, Blob *pB){
+int blob_compare(const Blob *pA, const Blob *pB){
   int szA, szB, sz, rc;
   blob_is_init(pA);
   blob_is_init(pB);
@@ -658,7 +680,7 @@ void blob_rewind(Blob *p){
 ** Truncate a blob back to zero length
 */
 void blob_truncate(Blob *p, int sz){
-  if( sz>=0 && sz<p->nUsed ) p->nUsed = sz;
+  if( sz>=0 && sz<(int)(p->nUsed) ) p->nUsed = sz;
 }
 
 /*
@@ -913,6 +935,25 @@ void blobarray_reset(Blob *aBlob, int n){
   int i;
   for(i=0; i<n; i++) blob_reset(&aBlob[i]);
 }
+/*
+** Allocate array of n blobs and initialize each element with `empty_blob`
+*/
+Blob* blobarray_new(int n){
+  int i;
+  Blob *aBlob = fossil_malloc(sizeof(Blob)*n);
+  for(i=0; i<n; i++) aBlob[i] = empty_blob;
+  return aBlob;
+}
+/*
+** Free array of n blobs some of which may be empty (have NULL buffer)
+*/
+void blobarray_delete(Blob *aBlob, int n){
+  int i;
+  for(i=0; i<n; i++){
+    if( blob_buffer(aBlob+i) ) blob_reset(aBlob+i);
+  }
+  fossil_free(aBlob);
+}
 
 /*
 ** Parse a blob into space-separated tokens.  Store each token in
@@ -1124,7 +1165,7 @@ int blob_write_to_file(Blob *pBlob, const char *zFilename){
     blob_is_init(pBlob);
     nWrote = fwrite(blob_buffer(pBlob), 1, blob_size(pBlob), out);
     fclose(out);
-    if( nWrote!=blob_size(pBlob) ){
+    if( nWrote!=(int)blob_size(pBlob) ){
       fossil_fatal_recursive("short write: %d of %d bytes to %s", nWrote,
          blob_size(pBlob), zFilename);
     }
@@ -1322,7 +1363,7 @@ void blob_add_cr(Blob *p){
     if( z[i]=='\n' ) n++;
   }
   j += n;
-  if( j>=p->nAlloc ){
+  if( j>=(int)(p->nAlloc) ){
     blob_resize(p, j);
     z = p->aData;
   }
@@ -1377,7 +1418,7 @@ void blob_cp1252_to_utf8(Blob *p){
     }
   }
   j += n;
-  if( j>=p->nAlloc ){
+  if( j>=(int)(p->nAlloc) ){
     blob_resize(p, j);
     z = (unsigned char *)p->aData;
   }
