@@ -96,13 +96,15 @@
 ** or cookie "x", or NULL if there is no such parameter or cookie.  PD("x","y")
 ** does the same except "y" is returned in place of NULL if there is not match.
 */
-#define P(x)        cgi_parameter((x),0)
-#define PD(x,y)     cgi_parameter((x),(y))
-#define PT(x)       cgi_parameter_trimmed((x),0)
-#define PDT(x,y)    cgi_parameter_trimmed((x),(y))
-#define PB(x)       cgi_parameter_boolean(x)
-#define PCK(x)      cgi_parameter_checked(x,1)
-#define PIF(x,y)    cgi_parameter_checked(x,y)
+#define P(x)          cgi_parameter((x),0)
+#define PD(x,y)       cgi_parameter((x),(y))
+#define PT(x)         cgi_parameter_trimmed((x),0)
+#define PDT(x,y)      cgi_parameter_trimmed((x),(y))
+#define PB(x)         cgi_parameter_boolean(x)
+#define PCK(x)        cgi_parameter_checked(x,1)
+#define PIF(x,y)      cgi_parameter_checked(x,y)
+#define P_NoBot(x)    cgi_parameter_nosql((x),0)
+#define PD_NoBot(x,y) cgi_parameter_nosql((x),(y))
 
 /*
 ** Shortcut for the cgi_printf() routine.  Instead of using the
@@ -309,7 +311,7 @@ void cgi_set_cookie(
     zPath = g.zTop;
     if( zPath[0]==0 ) zPath = "/";
   }
-  if( g.zBaseURL!=0 && strncmp(g.zBaseURL, "https:", 6)==0 ){
+  if( g.zBaseURL!=0 && fossil_strncmp(g.zBaseURL, "https:", 6)==0 ){
     zSecure = " secure;";
   }
   if( lifetime!=0 ){
@@ -332,9 +334,33 @@ void cgi_set_cookie(
 static int is_gzippable(void){
   if( g.fNoHttpCompress ) return 0;
   if( strstr(PD("HTTP_ACCEPT_ENCODING", ""), "gzip")==0 ) return 0;
-  return strncmp(zContentType, "text/", 5)==0
-    || sqlite3_strglob("application/*xml", zContentType)==0
-    || sqlite3_strglob("application/*javascript", zContentType)==0;
+  /* Maintenance note: this oddball structure is intended to make
+  ** adding new mimetypes to this list less of a performance hit than
+  ** doing a strcmp/glob over a growing set of compressible types. */
+  switch(zContentType ? *zContentType : 0){
+    case (int)'a':
+      if(0==fossil_strncmp("application/",zContentType,12)){
+        const char * z = &zContentType[12];
+        switch(*z){
+          case (int)'j':
+            return fossil_strcmp("javascript", z)==0
+                || fossil_strcmp("json", z)==0;
+          case (int)'w': return fossil_strcmp("wasm", z)==0;
+          case (int)'x':
+            return fossil_strcmp("x-tcl", z)==0
+                || fossil_strcmp("x-tar", z)==0;
+          default:
+            return sqlite3_strglob("*xml", z)==0;
+        }
+      }
+      break;
+    case (int)'i':
+      return fossil_strcmp(zContentType, "image/svg+xml")==0
+        || fossil_strcmp(zContentType, "image/vnd.microsoft.icon")==0;
+    case (int)'t':
+      return fossil_strncmp(zContentType, "text/", 5)==0;
+  }
+  return 0;
 }
 
 
@@ -421,6 +447,25 @@ static void cgi_fflush(void){
   }
 }
 
+/*
+** Given a Content-Type value, returns a string suitable for appending
+** to the Content-Type header for adding (or not) the "; charset=..."
+** part. It returns an empty string for most types or if zContentType
+** is NULL.
+**
+** See forum post f60dece061c364d1 for the discussions which lead to
+** this. Previously we always appended the charset, but WASM loaders
+** are pedantic and refuse to load any responses which have a
+** charset. Also, adding a charset is not strictly appropriate for
+** most types (and not required for many others which may ostensibly
+** benefit from one, as detailed in that forum post).
+*/
+static const char * content_type_charset(const char *zContentType){
+  if(0==fossil_strncmp(zContentType,"text/",5)){
+    return "; charset=utf-8";
+  }
+  return "";
+}
 
 /*
 ** Generate the reply to a web request.  The output might be an
@@ -495,7 +540,8 @@ void cgi_reply(void){
   ** the browser, not some shared location.
   */
   if( iReplyStatus!=304 ) {
-    blob_appendf(&hdr, "Content-Type: %s; charset=utf-8\r\n", zContentType);
+    blob_appendf(&hdr, "Content-Type: %s%s\r\n", zContentType,
+                 content_type_charset(zContentType));
     if( fossil_strcmp(zContentType,"application/x-fossil")==0 ){
       cgi_combine_header_and_body();
       blob_compress(&cgiContent[0], &cgiContent[0]);
@@ -571,7 +617,8 @@ NORETURN void cgi_redirect_with_status(
 ){
   char *zLocation;
   CGIDEBUG(("redirect to %s\n", zURL));
-  if( strncmp(zURL,"http:",5)==0 || strncmp(zURL,"https:",6)==0 ){
+  if( fossil_strncmp(zURL,"http:",5)==0
+      || fossil_strncmp(zURL,"https:",6)==0 ){
     zLocation = mprintf("Location: %s\r\n", zURL);
   }else if( *zURL=='/' ){
     int n1 = (int)strlen(g.zBaseURL);
@@ -637,6 +684,22 @@ const char *cgi_referer(const char *zDefault){
   return zRef;
 }
 
+
+/*
+** Return true if the current request is coming from the same origin.
+*/
+int cgi_same_origin(void){
+  const char *zRef;
+  int nBase;
+  if( g.zBaseURL==0 ) return 0;
+  zRef = P("HTTP_REFERER");
+  if( zRef==0 ) return 0;
+  nBase = (int)strlen(g.zBaseURL);
+  if( fossil_strncmp(g.zBaseURL,zRef,nBase)!=0 ) return 0;
+  if( zRef[nBase]!=0 && zRef[nBase]!='/' ) return 0;
+  return 1;
+}
+
 /*
 ** Return true if the current request appears to be safe from a
 ** Cross-Site Request Forgery (CSRF) attack.  Conditions that must
@@ -646,18 +709,12 @@ const char *cgi_referer(const char *zDefault){
 **    *   The REQUEST_METHOD must be POST - or requirePost==0
 */
 int cgi_csrf_safe(int requirePost){
-  const char *zRef = P("HTTP_REFERER");
-  int nBase;
-  if( zRef==0 ) return 0;
   if( requirePost ){
     const char *zMethod = P("REQUEST_METHOD");
     if( zMethod==0 ) return 0;
     if( strcmp(zMethod,"POST")!=0 ) return 0;
   }
-  nBase = (int)strlen(g.zBaseURL);
-  if( strncmp(g.zBaseURL,zRef,nBase)!=0 ) return 0;
-  if( zRef[nBase]!=0 && zRef[nBase]!='/' ) return 0;
-  return 1;
+  return cgi_same_origin();
 }
 
 /*
@@ -922,7 +979,8 @@ static char *get_bounded_content(
   int nBoundary = strlen(zBoundary);
   *pnContent = len;
   for(i=0; i<len; i++){
-    if( z[i]=='\n' && strncmp(zBoundary, &z[i+1], nBoundary)==0 ){
+    if( z[i]=='\n' && fossil_strncmp(zBoundary, &z[i+1],
+                                     nBoundary)==0 ){
       if( i>0 && z[i-1]=='\r' ) i--;
       z[i] = 0;
       *pnContent = i;
@@ -1155,11 +1213,15 @@ int cgi_setup_query_string(void){
     z = fossil_strdup(z);
     add_param_list(z, '&');
     z = (char*)P("skin");
-    if(z){
+    if( z ){
       char *zErr = skin_use_alternative(z, 2);
       ++rc;
-      if(!zErr && !P("once")){
+      if( !zErr && P("once")==0 ){
         cookie_write_parameter("skin","skin",z);
+        /* Per /chat discussion, passing ?skin=... without "once"
+        ** implies the "udc" argument, so we force that into the
+        ** environment here. */
+        cgi_set_parameter_nocopy("udc", "1", 1);
       }
       fossil_free(zErr);
     }
@@ -1350,7 +1412,7 @@ void cgi_decode_post_parameters(void){
   int len = blob_size(&g.cgiIn);
   if( len==0 ) return;
   if( fossil_strcmp(g.zContentType,"application/x-www-form-urlencoded")==0
-   || strncmp(g.zContentType,"multipart/form-data",19)==0
+   || fossil_strncmp(g.zContentType,"multipart/form-data",19)==0
   ){
     char *z = blob_str(&g.cgiIn);
     cgi_trace(z);
@@ -1447,6 +1509,62 @@ const char *cgi_parameter(const char *zName, const char *zDefault){
   return zDefault;
 }
 
+/*
+** Renders the "begone, spider" page and exits.
+*/
+static void cgi_begone_spider(void){
+  Blob content = empty_blob;
+
+  cgi_set_content(&content);
+  style_set_current_feature("test");
+  style_header("Malicious Query Detected");
+  @ <h2>Begone, Fiend!</h2>
+  @ <p>This page was generated because Fossil believes it has
+  @ detected an SQL injection attack. If you believe you are seeing
+  @ this in error, contact the developers on the Fossil-SCM Forum.  Type
+  @ "fossil-scm forum" into any search engine to locate the Fossil-SCM Forum.
+  style_finish_page();
+  cgi_set_status(404,"Robot Attack Detected");
+  cgi_reply();
+  exit(0);
+}
+
+/*
+** If looks_like_sql_injection() returns true for the given string, calls
+** cgi_begone_spider() and does not return, else this function has no
+** side effects. The range of checks performed by this function may
+** be extended in the future.
+**
+** Checks are omitted for any logged-in user.
+**
+** This is NOT a defense against SQL injection.  Fossil should easily be
+** proof against SQL injection without this routine.  Rather, this is an
+** attempt to avoid denial-of-service caused by persistent spiders that hammer
+** the server with dozens or hundreds of SQL injection attempts per second
+** against pages (such as /vdiff) that are expensive to compute.  In other
+** words, this is an effort to reduce the CPU load imposed by malicious
+** spiders.  It is not an effect defense against SQL injection vulnerabilities.
+*/
+void cgi_value_spider_check(const char *zTxt){
+  if( g.zLogin==0 && looks_like_sql_injection(zTxt) ){
+    cgi_begone_spider();
+  }
+}
+
+/*
+** A variant of cgi_parameter() with the same semantics except that if
+** cgi_parameter(zName,zDefault) returns a value other than zDefault
+** then it passes that value to cgi_value_spider_check().
+*/
+const char *cgi_parameter_nosql(const char *zName, const char *zDefault){
+  const char *zTxt = cgi_parameter(zName, zDefault);
+
+  if( zTxt!=zDefault ){
+    cgi_value_spider_check(zTxt);
+  }
+  return zTxt;
+}
+
 /*
 ** Return the value of the first defined query parameter or cookie whose
 ** name appears in the list of arguments.  Or if no parameter is found,
@@ -2284,7 +2402,7 @@ int cgi_http_server(
     inaddr.sin_family = AF_INET;
     if( zIpAddr ){
       inaddr.sin_addr.s_addr = inet_addr(zIpAddr);
-      if( inaddr.sin_addr.s_addr == (-1) ){
+      if( inaddr.sin_addr.s_addr == INADDR_NONE ){
         fossil_fatal("not a valid IP address: %s", zIpAddr);
       }
     }else if( flags & HTTP_SERVER_LOCALHOST ){
@@ -2311,7 +2429,7 @@ int cgi_http_server(
   }
   if( iPort>mxPort ){
     if( mnPort==mxPort ){
-      fossil_fatal("unable to open listening socket on ports %d", mnPort);
+      fossil_fatal("unable to open listening socket on port %d", mnPort);
     }else{
       fossil_fatal("unable to open listening socket on any"
                    " port in the range %d..%d", mnPort, mxPort);
@@ -2328,7 +2446,7 @@ int cgi_http_server(
     zBrowser = mprintf(zBrowser /*works-like:"%d"*/, iPort);
 #if defined(__CYGWIN__)
     /* On Cygwin, we can do better than "echo" */
-    if( strncmp(zBrowser, "echo ", 5)==0 ){
+    if( fossil_strncmp(zBrowser, "echo ", 5)==0 ){
       wchar_t *wUrl = fossil_utf8_to_unicode(zBrowser+5);
       wUrl[wcslen(wUrl)-2] = 0; /* Strip terminating " &" */
       if( (size_t)ShellExecuteW(0, L"open", wUrl, 0, 0, 1)<33 ){
@@ -2488,7 +2606,7 @@ time_t cgi_rfc822_parsedate(const char *zDate){
                        &mday, zMonth, &year, &hour, &min, &sec)){
     if( year > 1900 ) year -= 1900;
     for(mon=0; azMonths[mon]; mon++){
-      if( !strncmp( azMonths[mon], zMonth, 3 )){
+      if( !fossil_strncmp( azMonths[mon], zMonth, 3 )){
         int nDay;
         int isLeapYr;
         static int priorDays[] =
