@@ -33,31 +33,36 @@
 ** and "--offset P" options limits the output to the first N changes
 ** after skipping P changes.
 **
-** The -i mode will print the artifact ID of FILENAME given the REVISION
-** provided by the -r flag (which is required).
+** The -i mode will print various facts about FILENAME, including its
+** hash and the check-in and time when the current version of the file
+** was created.  Use -v for additional information.  Add the -r VERSION
+** option to see similar information about the same file for the check-in
+** specified by VERSION.
 **
 ** In the -s mode prints the status as <status> <revision>.  This is
 ** a quick status and does not check for up-to-date-ness of the file.
 **
 ** In the -p mode, there's an optional flag "-r|--revision REVISION".
-** The specified version (or the latest checked out version) is printed
+** The specified version (or the latest checked-out version) is printed
 ** to stdout.  The -p mode is another form of the "cat" command.
 **
 ** Options:
 **   -b|--brief           Display a brief (one line / revision) summary
 **   --case-sensitive B   Enable or disable case-sensitive filenames.  B is a
-**                        boolean: "yes", "no", "true", "false", etc.
-**   -i|--id              Print the artifact ID (requires -r)
+**                          boolean: "yes", "no", "true", "false", etc.
+**   -i|--id              Print the artifact ID
 **   -l|--log             Select log mode (the default)
 **   -n|--limit N         Display the first N changes (default unlimited).
-**                        N less than 0 means no limit.
+**                          N less than 0 means no limit.
 **   --offset P           Skip P changes
 **   -p|--print           Select print mode
 **   -r|--revision R      Print the given revision (or ckout, if none is given)
-**                        to stdout (only in print mode)
+**                          to stdout (only in print mode)
 **   -s|--status          Select status mode (print a status indicator for FILE)
+**   -v|--verbose         On the -i option, show all check-ins that use the
+**                          file, not just the earliest check-in
 **   -W|--width N         Width of lines (default is to auto-detect). Must be
-**                        more than 22 or else 0 to indicate no limit.
+**                          more than 22 or else 0 to indicate no limit.
 **
 ** See also: [[artifact]], [[cat]], [[descendants]], [[info]], [[leaves]]
 */
@@ -75,7 +80,7 @@ void finfo_cmd(void){
     if( g.argc!=3 ) usage("-s|--status FILENAME");
     vid = db_lget_int("checkout", 0);
     if( vid==0 ){
-      fossil_fatal("no checkout to finfo files in");
+      fossil_fatal("no check-out to finfo files in");
     }
     vfile_check_signature(vid, CKSIG_ENOTFILE);
     file_tree_name(g.argv[2], &fname, 0, 1);
@@ -144,12 +149,14 @@ void finfo_cmd(void){
   }else if( find_option("id","i",0) ){
     Blob fname;
     int rid;
+    int whatisFlags = WHATIS_BRIEF;
     const char *zRevision = find_option("revision", "r", 1);
+    if( find_option("verbose","v",0)!=0 ) whatisFlags = 0;
 
     verify_all_options();
 
-    if( zRevision==0 ) usage("-i|--id also requires -r|--revision");
-    if( g.argc!=3 ) usage("-r|--revision REVISION FILENAME");
+    if( zRevision==0 ) zRevision = "current";
+    if( g.argc!=3 ) usage("FILENAME");
     file_tree_name(g.argv[2], &fname, 0, 1);
     rid = db_int(0, "SELECT rid FROM blob WHERE uuid ="
                     "  (SELECT uuid FROM files_of_checkin(%Q)"
@@ -159,7 +166,7 @@ void finfo_cmd(void){
       fossil_fatal("file not found for revision %s: %s",
                    zRevision, blob_str(&fname));
     }
-    whatis_rid(rid,0);
+    whatis_rid(rid,whatisFlags);
     blob_reset(&fname);
   }else{
     Blob line;
@@ -553,7 +560,7 @@ void finfo_page(void){
     blob_appendf(&title, "History of the file that is called ");
     hyperlinked_path(zFilename, &title, 0, "tree", "", LINKPATH_FILE);
     if( fShowId ) blob_appendf(&title, " (%d)", fnid);
-    blob_appendf(&title, " at checkin %z%h</a>",
+    blob_appendf(&title, " at check-in %z%h</a>",
         href("%R/info?name=%t",zCI), zCI);
   }else{
     blob_appendf(&title, "History for ");
@@ -676,6 +683,14 @@ void finfo_page(void){
       }
       if( (tmFlags & TIMELINE_VERBOSE)!=0 && zUuid ){
         hyperlink_to_version(zUuid);
+        if( fShowId ){
+          int srcId = delta_source_rid(frid);
+          if( srcId ){
+            @ (%z(href("%R/deltachain/%d",frid))%d(frid)&larr;%d(srcId)</a>)
+          }else{
+            @ (%z(href("%R/deltachain/%d",frid))%d(frid)</a>)
+          }
+        }
         @ part of check-in \
         hyperlink_to_version(zCkin);
       }
@@ -703,9 +718,10 @@ void finfo_page(void){
       if( fShowId ){
         int srcId = delta_source_rid(frid);
         if( srcId>0 ){
-          @ id:&nbsp;%d(frid)&larr;%d(srcId)
+          @ id:&nbsp;%z(href("%R/deltachain/%d",frid))\
+          @ %d(frid)&larr;%d(srcId)</a>
         }else{
-          @ id:&nbsp;%d(frid)
+          @ id:&nbsp;%z(href("%R/deltachain/%d",frid))%d(frid)</a>
         }
       }
     }
