@@ -128,7 +128,8 @@ const char zRepositorySchema1[] =
 @   cexpire DATETIME,               -- Time when cookie expires
 @   info TEXT,                      -- contact information
 @   mtime DATE,                     -- last change.  seconds since 1970
-@   photo BLOB                      -- JPEG image of this user
+@   photo BLOB,                     -- JPEG image of this user
+@   jx TEXT DEFAULT '{}'            -- Extra fields in JSON
 @ );
 @
 @ -- The config table holds miscellanous information about the repository.
@@ -178,7 +179,8 @@ const char zRepositorySchema1[] =
 @    title TEXT UNIQUE,       -- Title of this report
 @    mtime DATE,              -- Last modified.  seconds since 1970
 @    cols TEXT,               -- A color-key specification
-@    sqlcode TEXT             -- An SQL SELECT statement for this report
+@    sqlcode TEXT,            -- An SQL SELECT statement for this report
+@    jx TEXT DEFAULT '{}'     -- Additional fields encoded as JSON
 @ );
 @
 @ -- Some ticket content (such as the originators email address or contact
@@ -460,6 +462,7 @@ const char zRepositorySchema2[] =
 @   tkt_id INTEGER REFERENCES ticket,
 @   tkt_rid INTEGER REFERENCES blob,
 @   tkt_mtime DATE,
+@   tkt_user TEXT,
 @   -- Add as many fields as required below this line
 @   login TEXT,
 @   username TEXT,
@@ -490,6 +493,17 @@ const char zRepositorySchema2[] =
 # define ValidBklnk(X)   (X>=0 && X<=4)  /* True if backlink.srctype is valid */
 #endif
 
+/*
+** Allowed values for MIMEtype codes
+*/
+#if INTERFACE
+# define MT_NONE       0   /* unspecified */
+# define MT_WIKI       1   /* Wiki */
+# define MT_MARKDOWN   2   /* Markdonw */
+# define MT_UNKNOWN    3   /* unknown  */
+# define ValidMTC(X)  ((X)>=0 && (X)<=3)  /* True if MIMEtype code is valid */
+#endif
+
 /*
 ** Predefined tagid values
 */
@@ -510,13 +524,13 @@ const char zRepositorySchema2[] =
 /*
 ** The schema for the local FOSSIL database file found at the root
 ** of every check-out.  This database contains the complete state of
-** the checkout.  See also the addendum in zLocalSchemaVmerge[].
+** the check-out.  See also the addendum in zLocalSchemaVmerge[].
 */
 const char zLocalSchema[] =
 @ -- The VVAR table holds miscellanous information about the local database
 @ -- in the form of name-value pairs.  This is similar to the VAR table
 @ -- table in the repository except that this table holds information that
-@ -- is specific to the local checkout.
+@ -- is specific to the local check-out.
 @ --
 @ -- Important Variables:
 @ --
@@ -530,7 +544,7 @@ const char zLocalSchema[] =
 @ );
 @
 @ -- Each entry in the vfile table represents a single file in the
-@ -- current checkout.
+@ -- current check-out.
 @ --
 @ -- The file.rid field is 0 for files or folders that have been
 @ -- added but not yet committed.
@@ -543,8 +557,8 @@ const char zLocalSchema[] =
 @ --    4,5     Same as 2,3 except merge using --integrate
 @ --
 @ CREATE TABLE vfile(
-@   id INTEGER PRIMARY KEY,           -- ID of the checked out file
-@   vid INTEGER REFERENCES blob,      -- The checkin this file is part of.
+@   id INTEGER PRIMARY KEY,           -- ID of the checked-out file
+@   vid INTEGER REFERENCES blob,      -- The check-in this file is part of.
 @   chnged INT DEFAULT 0,  -- 0:unchng 1:edit 2:m-chng 3:m-add 4:i-chng 5:i-add
 @   deleted BOOLEAN DEFAULT 0,        -- True if deleted
 @   isexe BOOLEAN,                    -- True if file should be executable
@@ -574,7 +588,7 @@ const char zLocalSchemaVmerge[] =
 @ -- merge is the RECORD table entry that the file merged against.
 @ -- An id of 0 or <-3 here means the version record itself.  When
 @ -- id==(-1) that is a cherrypick merge, id==(-2) that is a
-@ -- backout merge and id==(-4) is a integrate merge.
+@ -- backout merge and id==(-4) is an integrate merge.
 @ --
 @
 @ CREATE TABLE vmerge(
@@ -593,7 +607,7 @@ const char zLocalSchemaVmerge[] =
 @ CREATE TRIGGER vmerge_ck1 AFTER INSERT ON vmerge
 @ WHEN new.mhash IS NULL BEGIN
 @   SELECT raise(FAIL,
-@   'trying to update a newer checkout with an older version of Fossil');
+@   'trying to update a newer check-out with an older version of Fossil');
 @ END;
 @
 ;
