@@ -588,7 +588,10 @@ void user_edit(void){
   style_submenu_element("Cancel", "%s", cgi_referer("setup_ulist"));
   if( uid ){
     style_header("Edit User %h", zLogin);
-    style_submenu_element("Access Log", "%R/access_log?u=%t", zLogin);
+    if( !login_is_special(zLogin) ){
+      style_submenu_element("Access Log", "%R/access_log?u=%t", zLogin);
+      style_submenu_element("Timeline","%R/timeline?u=%t", zLogin);
+    }
   }else{
     style_header("Add A New User");
   }
@@ -732,7 +735,8 @@ void user_edit(void){
     if( zPw[0] ){
       /* Obscure the password for all users */
       @   <td><input aria-labelledby="supw" type="password" autocomplete="off" \
-      @   name="pw" value="**********" /></td>
+      @   name="pw" value="**********" />
+      @   (Leave unchanged to retain password)</td>
     }else{
       /* Show an empty password as an empty input field */
       char *zRPW = fossil_random_password(12);
