@@ -103,7 +103,7 @@ static int needHrefJs = 0;      /* href.js */
 static Blob blobOnLoad = BLOB_INITIALIZER;
 
 /*
-** Generate and return a anchor tag like this:
+** Generate and return an anchor tag like this:
 **
 **        <a href="URL">
 **  or    <a id="ID">
@@ -649,8 +649,8 @@ void style_disable_csp(void){
 static const char zDfltHeader[] = 
 @ <html>
 @ <head>
-@ <base href="$baseurl/$current_page" />
 @ <meta charset="UTF-8">
+@ <base href="$baseurl/$current_page" />
 @ <meta http-equiv="Content-Security-Policy" content="$default_csp" />
 @ <meta name="viewport" content="width=device-width, initial-scale=1.0">
 @ <title>$<project_name>: $<title></title>
@@ -658,7 +658,7 @@ static const char zDfltHeader[] =
 @  href="$home/timeline.rss" />
 @ <link rel="stylesheet" href="$stylesheet_url" type="text/css" />
 @ </head>
-@ <body class="$current_feature">
+@ <body class="$current_feature rpage-$requested_page cpage-$canonical_page">
 ;
 
 /*
@@ -771,6 +771,15 @@ static void style_init_th1_vars(const char *zTitle){
   Th_Store("index_page", db_get("index-page","/home"));
   if( local_zCurrentPage==0 ) style_set_current_page("%T", g.zPath);
   Th_Store("current_page", local_zCurrentPage);
+  if( g.zPath ){                /* store the first segment of a path; */
+    char *pSlash = strchr(g.zPath,'/');
+    if( pSlash ) *pSlash = 0;   /* make a temporary cut if necessary  */
+    Th_Store("requested_page", escape_quotes(g.zPath));
+    if( pSlash ) *pSlash = '/';
+  }else{
+    Th_Store("requested_page", "");
+  }
+  Th_Store("canonical_page", escape_quotes(g.zPhase+1));
   Th_Store("csrf_token", g.zCsrfToken);
   Th_Store("release_version", RELEASE_VERSION);
   Th_Store("manifest_version", MANIFEST_VERSION);
@@ -784,6 +793,13 @@ static void style_init_th1_vars(const char *zTitle){
     Th_Store("login", g.zLogin);
   }
   Th_MaybeStore("current_feature", feature_from_page_path(local_zCurrentPage) );
+  if( g.ftntsIssues[0] || g.ftntsIssues[1] ||
+      g.ftntsIssues[2] || g.ftntsIssues[3] ){
+    char buf[80];
+    sprintf(&buf[0],"%i %i %i %i",g.ftntsIssues[0],g.ftntsIssues[1],
+                                  g.ftntsIssues[2],g.ftntsIssues[3]);
+    Th_Store("footnotes_issues_counters", buf);
+  }
 }
 
 /*
@@ -887,7 +903,7 @@ static void style_load_all_js_files(void){
     int nDelay = db_get_int("auto-hyperlink-delay",0);
     int bMouseover = db_get_boolean("auto-hyperlink-mouseover",0)
                    && sqlite3_strglob("*Android*",PD("HTTP_USER_AGENT",""));
-    @ <script id='href-data' type='application/json'>\
+    @ <script id='href-data' type='text/json'>\
     @ {"delay":%d(nDelay),"mouseover":%d(bMouseover)}</script>
   }
   @ <script nonce="%h(style_nonce())">/* style.c:%d(__LINE__) */
@@ -908,6 +924,37 @@ static void style_load_all_js_files(void){
   builtin_fulfill_js_requests();
 }
 
+/*
+** Transorm input string into a token that is safe for inclusion into
+** class attribute. Digits and low-case letter are passed unchanged,
+** upper-case letters are transformed to low-case, everything else is
+** tranformed into hyphens; consequtive and pending hyphens are squeezed.
+** If result does not fit into szOut chars then it is truncated.
+** Result is always terminated with null.
+*/
+void style_derive_classname(const char *zIn, char *zOut, int szOut){
+  assert(  zOut );
+  assert( szOut>0 );
+  if( zIn ){
+    int n = 0;  /* number of chars written to zOut */
+    char c;
+    for(--szOut; (c=*zIn) && n<szOut; zIn++) {
+      if( ('a'<=c && c<='z') || ('0'<=c && c<='9') ){
+        *zOut = c;
+      }else if( 'A'<=c && c<='Z' ){
+        *zOut = c - 'A' + 'a';
+      }else{
+        if( n==0 || zOut[-1]=='-' ) continue;
+        *zOut = '-';
+      }
+      zOut++;
+      n++;
+    }
+    if( n && zOut[-1]=='-' ) zOut--;
+  }
+  *zOut = 0;
+}
+
 /*
 ** Invoke this routine after all of the content for a webpage has been
 ** generated.  This routine should be called once for every webpage, at
@@ -936,6 +983,7 @@ void style_finish_page(){
   cgi_destination(CGI_HEADER);
   if( submenuEnable && nSubmenu+nSubmenuCtrl>0 ){
     int i;
+    char zClass[32]; /* reduced form of the main attribute */
     if( nSubmenuCtrl ){
       @ <form id='f01' method='GET' action='%R/%s(g.zPath)'>
       @ <input type='hidden' name='udc' value='1'>
@@ -946,17 +994,20 @@ void style_finish_page(){
       qsort(aSubmenu, nSubmenu, sizeof(aSubmenu[0]), submenuCompare);
       for(i=0; i<nSubmenu; i++){
         struct Submenu *p = &aSubmenu[i];
+        style_derive_classname(p->zLabel, zClass, sizeof zClass);
         /* switching away from the %h formatting below might be dangerous
         ** because some places use %s to compose zLabel and zLink;
-        ** e.g. /rptview page
+        ** e.g. /rptview page and the submenuCmd() function.
+        ** "sml" stands for submenu link.
         */
         if( p->zLink==0 ){
-          @ <span class="label">%h(p->zLabel)</span>
+          @ <span class="label sml-%s(zClass)">%h(p->zLabel)</span>
         }else{
-          @ <a class="label" href="%h(p->zLink)">%h(p->zLabel)</a>
+          @ <a class="label sml-%s(zClass)" href="%h(p->zLink)">%h(p->zLabel)</a>
         }
       }
     }
+    strcpy(zClass,"smc-");   /* common prefix for submenu controls */
     for(i=0; i<nSubmenuCtrl; i++){
       const char *zQPN = aSubmenuCtrl[i].zName;
       const char *zDisabled = "";
@@ -966,9 +1017,10 @@ void style_finish_page(){
       }else if( zQPN ){
         cgi_tag_query_parameter(zQPN);
       }
+      style_derive_classname(zQPN, zClass+4, sizeof(zClass)-4);
       switch( aSubmenuCtrl[i].eType ){
         case FF_ENTRY:
-          @ <span class='submenuctrl%s(zXtraClass)'>\
+          @ <span class='submenuctrl%s(zXtraClass) %s(zClass)'>\
           @ &nbsp;%h(aSubmenuCtrl[i].zLabel)\
           @ <input type='text' name='%s(zQPN)' value='%h(PD(zQPN, ""))' \
           if( aSubmenuCtrl[i].iSize<0 ){
@@ -983,12 +1035,12 @@ void style_finish_page(){
           int j;
           const char *zVal = P(zQPN);
           if( zXtraClass[0] ){
-            @ <span class='%s(zXtraClass+1)'>
+            @ <span class='%s(zXtraClass+1) %s(zClass)'>
           }
           if( aSubmenuCtrl[i].zLabel ){
             @ &nbsp;%h(aSubmenuCtrl[i].zLabel)\
           }
-          @ <select class='submenuctrl' size='1' name='%s(zQPN)' \
+          @ <select class='submenuctrl %s(zClass)' size='1' name='%s(zQPN)' \
           @ id='submenuctrl-%d(i)'%s(zDisabled)>
           for(j=0; j<aSubmenuCtrl[i].iSize*2; j+=2){
             const char *zQPV = aSubmenuCtrl[i].azChoice[j];
@@ -1022,7 +1074,7 @@ void style_finish_page(){
           break;
         }
         case FF_CHECKBOX: {
-          @ <label class='submenuctrl submenuckbox%s(zXtraClass)'>\
+          @ <label class='submenuctrl submenuckbox%s(zXtraClass) %s(zClass)'>\
           @ <input type='checkbox' name='%s(zQPN)' id='submenuctrl-%d(i)' \
           if( PB(zQPN) ){
             @ checked \
@@ -1088,9 +1140,7 @@ void style_finish_page(){
     @ </body>
     @ </html>
   }
-  /* Update the user display prefs cookie if it was modified during
-  ** this request.
-  */
+  /* Update the user display prefs cookie if it was modified */
   cookie_render();
 }
 
@@ -1171,7 +1221,7 @@ void page_script_js(void){
     cgi_set_content_type("text/plain");
   }else{
     /* Default behavior is to return javascript */
-    cgi_set_content_type("application/javascript");
+    cgi_set_content_type("text/javascript");
   }
   style_init_th1_vars(0);
   Th_Render(zScript?zScript:"");
@@ -1212,7 +1262,7 @@ static void page_style_css_append_page_style(Blob *pOut){
 }
 
 /*
-** WEBPAGE: style.css
+** WEBPAGE: style.css loadavg-exempt
 **
 ** Return the style sheet.   The style sheet is assemblied from
 ** multiple sources, in order:
@@ -1391,6 +1441,11 @@ void webpage_error(const char *zFormat, ...){
     @ g.zLogin = %h(g.zLogin)<br />
     @ g.isHuman = %d(g.isHuman)<br />
     @ g.jsHref = %d(g.jsHref)<br />
+    if( g.zLocalRoot ){
+      @ g.zLocalRoot = %h(g.zLocalRoot)<br />
+    }else{
+      @ g.zLocalRoot = <i>none</i><br />
+    }
     if( g.nRequest ){
       @ g.nRequest = %d(g.nRequest)<br />
     }
