@@ -107,7 +107,7 @@ static int client_sync_all_urls(
 **
 **   SYNC_PULL           Pull content from the server to the local repo
 **   SYNC_PUSH           Push content from local up to the server
-**   SYNC_CKIN_LOCK      Take a check-in lock on the current checkout.
+**   SYNC_CKIN_LOCK      Take a check-in lock on the current check-out.
 **   SYNC_VERBOSE        Extra output
 **
 ** Return the number of errors.
@@ -321,7 +321,6 @@ static void process_sync_args(
 ** details on the URL formats.
 **
 ** Options:
-**
 **   --all                      Pull from all remotes, not just the default
 **   -B|--httpauth USER:PASS    Credentials for the simple HTTP auth protocol,
 **                              if required by the remote website
@@ -376,7 +375,6 @@ void pull_cmd(void){
 ** details on the URL formats.
 **
 ** Options:
-**
 **   --all                      Push to all remotes, not just the default
 **   -B|--httpauth USER:PASS    Credentials for the simple HTTP auth protocol,
 **                              if required by the remote website
@@ -425,7 +423,6 @@ void push_cmd(void){
 ** details on the URL formats.
 **
 ** Options:
-**
 **   --all                      Sync with all remotes, not just the default
 **   -B|--httpauth USER:PASS    Credentials for the simple HTTP auth protocol,
 **                              if required by the remote website
@@ -483,9 +480,10 @@ void sync_unversioned(unsigned syncFlags){
 ** Usage: %fossil remote ?SUBCOMMAND ...?
 **
 ** View or modify the URLs of remote repositories used for syncing.
-** The "default" remote is the URL used in the most recent "sync",
-** "push", "pull", "clone", or similar command.  The default remote can
-** change with each sync command.  Other named remotes are persistent.
+** The "default" remote is specially named by Fossil and corresponds to
+** the URL used in the most recent "sync", "push", "pull", "clone", or
+** similar command.  As such, the default remote can be updated by
+** Fossil with each sync command.  Other named remotes are persistent.
 **
 ** > fossil remote
 **
@@ -496,8 +494,10 @@ void sync_unversioned(unsigned syncFlags){
 **
 **     Add a new named URL. Afterwards, NAME can be used as a short
 **     symbolic name for URL in contexts where a URL is required. The
-**     URL argument can be "default" or a prior symbolic name, to make
-**     a copy of an existing URL under a new name.
+**     URL argument can be "default" or a prior symbolic name to make
+**     a copy of an existing URL under the new NAME. The "default"
+**     remote cannot be defined with this subcommand; instead,
+**     use 'fossil remote REF' as documented below.
 **
 ** > fossil remote config-data
 **
@@ -509,6 +509,14 @@ void sync_unversioned(unsigned syncFlags){
 **
 **     Delete a named URL previously created by the "add" subcommand.
 **
+** > fossil remote hyperlink ?FILENAME? ?LINENUM? ?LINENUM?
+**
+**     Print a URL that will access the current check-out on the remote
+**     repository.  Or if the FILENAME argument is included, print the
+**     URL to access that particular file within the current check-out.
+**     If one or two linenumber arguments are provided after the filename,
+**     then the URL is for the line or range of lines specified.
+**
 ** > fossil remote list|ls
 **
 **     Show all remote repository URLs.
@@ -534,6 +542,15 @@ void sync_unversioned(unsigned syncFlags){
 **     to remember the URLs themselves.  You will be prompted for the
 **     password the next time it is needed.
 **
+** > fossil remote ui ?FILENAME? ?LINENUM? ?LINENUM?
+**
+**     Bring up a web browser pointing at the remote repository, and
+**     specifically to the page that describes the current check-out
+**     on that remote repository.  Or if FILENAME and/or LINENUM arguments
+**     are provided, to the specific file and range of lines.  This
+**     command is similar to "fossil remote hyperlink" except that instead
+**     of printing the URL, it passes the URL off to the web browser.
+**
 ** > fossil remote REF
 **
 **     Make REF the new default URL, replacing the prior default.
@@ -542,7 +559,9 @@ void sync_unversioned(unsigned syncFlags){
 void remote_url_cmd(void){
   char *zUrl, *zArg;
   int nArg;
+  int showPw;
   db_find_and_open_repository(0, 0);
+  showPw = find_option("show-passwords",0,0)!=0;
 
   /* We should be done with options.. */
   verify_all_options();
@@ -618,7 +637,10 @@ remote_delete_default:
     memset(&x, 0, sizeof(x));
     zName = g.argv[3];
     zUrl = g.argv[4];
-    if( strcmp(zName,"default")==0 ) goto remote_add_default;
+    if( strcmp(zName,"default")==0 ){
+      fossil_fatal("update the \"default\" remote-url with 'fossil remote REF'"
+          "\nsee 'fossil help remote' for complete usage information");
+    }
     db_begin_write();
     if( fossil_strcmp(zUrl,"default")==0 ){
       x.canonical = db_get("last-sync-url",0);
@@ -654,6 +676,80 @@ remote_delete_default:
     db_commit_transaction();
     return;
   }
+  if( strncmp(zArg, "hyperlink", nArg)==0
+   || (nArg==2 && strcmp(zArg, "ui")==0)
+  ){
+    char *zBase;
+    char *zUuid;
+    Blob fname;
+    Blob url;
+    char *zSubCmd = g.argv[2][0]=='u' ? "ui" : "hyperlink";
+    if( !db_table_exists("localdb","vvar") ){
+      fossil_fatal("the \"remote %s\" command only works from "
+                   "within an open check-out", zSubCmd);
+    }
+    zUrl = db_get("last-sync-url", 0);
+    if( zUrl==0 ){
+      zUrl = "http://localhost:8080/";
+    }
+    url_parse(zUrl, 0);
+    if( g.url.isFile ){
+      url_parse("http://localhost:8080/", 0);
+    }
+    zBase = url_nouser(&g.url);
+    blob_init(&url, 0, 0);
+    if( g.argc==3 ){
+      blob_appendf(&url, "%s/info/%!S",
+        zBase,
+        db_text("???",
+          "SELECT uuid FROM blob, vvar"
+          " WHERE blob.rid=0+vvar.value"
+          "   AND vvar.name='checkout';"
+        ));
+    }else{
+      blob_init(&fname, 0, 0);
+      file_tree_name(g.argv[3], &fname, 0, 1);
+      zUuid = db_text(0,
+        "SELECT uuid FROM files_of_checkin"
+        " WHERE checkinID=(SELECT value FROM vvar WHERE name='checkout')"
+        "   AND filename=%Q",
+        blob_str(&fname)
+      );
+      if( zUuid==0 ){
+        fossil_fatal("not a managed file: \"%s\"", g.argv[3]);
+      }
+      blob_appendf(&url, "%s/info/%S",zBase,zUuid);
+      if( g.argc>4 ){
+        int ln1 = atoi(g.argv[4]);
+        if( ln1<=0 || sqlite3_strglob("*[^0-9]*",g.argv[4])==0 ){
+          fossil_fatal("\"%s\" is not a valid line number", g.argv[4]);
+        }
+        if( g.argc>5 ){
+          int ln2 = atoi(g.argv[5]);
+          if( ln2==0 || sqlite3_strglob("*[^0-9]*",g.argv[5])==0 ){
+            fossil_fatal("\"%s\" is not a valid line number", g.argv[5]);
+          }
+          if( ln2<=ln1 ){
+            fossil_fatal("second line number should be greater than the first");
+          }
+          blob_appendf(&url,"?ln=%d,%d", ln1, ln2);
+        }else{
+          blob_appendf(&url,"?ln=%d", ln1);
+        }
+      }
+      if( g.argc>6 ){
+        usage(mprintf("%s ?FILENAME? ?LINENUMBER? ?LINENUMBER?", zSubCmd));
+      }
+    }
+    if( g.argv[2][0]=='u' ){
+      char *zCmd;
+      zCmd = mprintf("%s %!$ &", fossil_web_browser(), blob_str(&url));
+      fossil_system(zCmd);
+    }else{
+      fossil_print("%s\n", blob_str(&url));
+    }
+    return;
+  }
   if( strncmp(zArg, "scrub", nArg)==0 ){
     if( g.argc!=3 ) usage("scrub");
     db_begin_write();
@@ -665,24 +761,33 @@ remote_delete_default:
     return;
   }
   if( strncmp(zArg, "config-data", nArg)==0 ){
-    /* Undocumented command:  "fossil remote config-data"
+    /* Undocumented command:  "fossil remote config-data [-show-passwords]"
     **
     ** Show the CONFIG table entries that relate to remembering remote URLs
     */
     Stmt q;
     int n;
+    sqlite3_create_function(g.db, "unobscure", 1, SQLITE_UTF8, &g.db,
+                            db_obscure, 0, 0);
     n = db_int(13,
        "SELECT max(length(name))"
        "  FROM config"
-       " WHERE name GLOB 'sync-*:*' OR name GLOB 'last-sync-*'"
+       " WHERE name GLOB 'sync-*:*'"
+          " OR name GLOB 'last-sync-*'"
+          " OR name GLOB 'parent-project-*'"
     );
     db_prepare(&q,
-       "SELECT name,"
-       "       CASE WHEN name LIKE '%%sync-pw%%'"
-                  " THEN printf('%%.*c',length(value),'*') ELSE value END"
-       "  FROM config"
-       " WHERE name GLOB 'sync-*:*' OR name GLOB 'last-sync-*'"
-       " ORDER BY name LIKE '%%sync-pw%%', name"
+      "SELECT name,"
+      "  CASE WHEN name NOT LIKE '%%sync-pw%%' AND name<>'parent-project-pw'"
+      "       THEN value"
+      "       WHEN %d THEN unobscure(value)"
+      "       ELSE printf('%%.*c',length(value)/2-1,'*') END"
+      "  FROM config"
+      " WHERE name GLOB 'sync-*:*'"
+         " OR name GLOB 'last-sync-*'"
+         " OR name GLOB 'parent-project-*'"
+      " ORDER BY name LIKE '%%sync-pw%%' OR name='parent-project-pw', name",
+      showPw
     );
     while( db_step(&q)==SQLITE_ROW ){
       fossil_print("%-*s  %s\n",
@@ -699,7 +804,6 @@ remote_delete_default:
    || sqlite3_strlike("file:%",zArg,0)==0
    || db_exists("SELECT 1 FROM config WHERE name='sync-url:%q'",zArg)
   ){
-remote_add_default:
     db_unset("last-sync-url", 0);
     db_unset("last-sync-pw", 0);
     url_parse(g.argv[2], URL_REMEMBER|URL_PROMPT_PW|
@@ -708,7 +812,7 @@ remote_add_default:
     return;
   }
   fossil_fatal("unknown command \"%s\" - should be a URL or one of: "
-               "add delete list off", zArg);
+               "add delete hyperlink list off scrub", zArg);
 }
 
 /*
@@ -722,11 +826,10 @@ remote_add_default:
 ** is safe to run "fossil backup" on a repository that is in active use.
 **
 ** Only the main repository database is backed up by this command.  The
-** open checkout file (if any) is not saved.  Nor is the global configuration
+** open check-out file (if any) is not saved.  Nor is the global configuration
 ** database.
 **
 ** Options:
-**
 **    --overwrite              OK to overwrite an existing file
 **    -R NAME                  Filename of the repository to backup
 */
