@@ -284,7 +284,7 @@ void testtag_cmd(void){
 /*
 ** OR this value into the tagtype argument to tag_add_artifact to
 ** cause the tag to be displayed on standard output rather than be
-** inserted.  Used for --dryrun options and debugging.
+** inserted.  Used for --dry-run options and debugging.
 */
 #if INTERFACE
 #define TAG_ADD_DRYRUN  0x04
@@ -397,7 +397,7 @@ static void tag_cmd_tagname_check(const char *zTag){
 ** > fossil tag add ?OPTIONS? TAGNAME ARTIFACT-ID ?VALUE?
 **
 **         Add a new tag or property to an artifact referenced by
-**         ARTIFACT-ID. For checkins, the tag will be usable instead
+**         ARTIFACT-ID. For check-ins, the tag will be usable instead
 **         of a CHECK-IN in commands such as update and merge. If the
 **         --propagate flag is present and ARTIFACT-ID refers to a
 **         wiki page, forum post, technote, or check-in, the tag
@@ -406,11 +406,11 @@ static void tag_cmd_tagname_check(const char *zTag){
 **         Options:
 **           --raw                      Raw tag name. Ignored for
 **                                      non-CHECK-IN artifacts.
-**           --propagate                Propagating tag.
-**           --date-override DATETIME   Set date and time added.
-**           --user-override USER       Name USER when adding the tag.
-**           -n|--dryrun                Display the tag text, but do not
-**                                      actually insert it into the database.
+**           --propagate                Propagating tag
+**           --date-override DATETIME   Set date and time added
+**           --user-override USER       Name USER when adding the tag
+**           -n|--dry-run               Display the tag text, but do not
+**                                      actually insert it into the database
 **
 **         The --date-override and --user-override options support
 **         importing history from other SCM systems. DATETIME has
@@ -424,17 +424,17 @@ static void tag_cmd_tagname_check(const char *zTag){
 **
 **         Remove the tag TAGNAME from the artifact referenced by
 **         ARTIFACT-ID, and also remove the propagation of the tag to
-**         any descendants.  Use the the -n|--dryrun option to see
+**         any descendants.  Use the the -n|--dry-run option to see
 **         what would have happened. Certain tag name prefixes are
 **         forbidden, as documented for the 'add' subcommand.
 **
 **         Options:
 **           --raw                       Raw tag name. Ignored for
 **                                       non-CHECK-IN artifacts.
-**           --date-override DATETIME    Set date and time deleted.
-**           --user-override USER        Name USER when deleting the tag.
-**           -n|--dryrun                 Display the control artifact, but do
-**                                       not insert it into the database.
+**           --date-override DATETIME    Set date and time deleted
+**           --user-override USER        Name USER when deleting the tag
+**           -n|--dry-run                Display the control artifact, but do
+**                                       not insert it into the database
 **
 ** > fossil tag find ?OPTIONS? TAGNAME
 **
@@ -449,7 +449,7 @@ static void tag_cmd_tagname_check(const char *zTag){
 **                           e (event/technote), f (forum post),
 **                           t (ticket). Default is all types. Ignored
 **                           if --raw is used.
-**           -n|--limit N    Limit to N results.
+**           -n|--limit N    Limit to N results
 **
 ** > fossil tag list|ls ?OPTIONS? ?ARTIFACT-ID?
 **
@@ -464,8 +464,8 @@ static void tag_cmd_tagname_check(const char *zTag){
 **           --raw           List raw names of tags
 **           --tagtype TYPE  List only tags of type TYPE, which must
 **                           be one of: cancel, singleton, propagated
-**           -v|--inverse    Inverse the meaning of --tagtype TYPE.
-**           --prefix        List only tags with the given prefix.
+**           -v|--inverse    Inverse the meaning of --tagtype TYPE
+**           --prefix        List only tags with the given prefix
 **                           Fossil-internal prefixes include "sym-"
 **                           (branch name), "wiki-", "event-"
 **                           (technote), and "tkt-" (ticket). The
@@ -516,7 +516,7 @@ void tag_cmd(void){
     const char *zTag;
     const char *zObjId;
     int objType;
-    if( find_option("dryrun","n",0)!=0 ) dryRun = TAG_ADD_DRYRUN;
+    if( find_option("dry-run","n",0)!=0 ) dryRun = TAG_ADD_DRYRUN;
     if( g.argc!=5 && g.argc!=6 ){
       usage("add ?options? TAGNAME ARTIFACT-ID ?VALUE?");
     }
@@ -554,7 +554,7 @@ void tag_cmd(void){
     const char *zTag;
     const char *zObjId;
     int objType;
-    if( find_option("dryrun","n",0)!=0 ) dryRun = TAG_ADD_DRYRUN;
+    if( find_option("dry-run","n",0)!=0 ) dryRun = TAG_ADD_DRYRUN;
     if( g.argc!=5 ){
       usage("cancel ?options? TAGNAME ARTIFACT-ID");
     }
@@ -753,7 +753,7 @@ tag_cmd_usage:
 **    --test           Make database entries but do not add the tag artifact.
 **                     So the reparent operation will be undone by the next
 **                     "fossil rebuild" command.
-**    -n|--dryrun      Print the tag that would have been created but do not
+**    -n|--dry-run     Print the tag that would have been created but do not
 **                     actually change the database in any way.
 **    --date-override DATETIME  Set the change time on the control artifact
 **    --user-override USER      Set the user name on the control artifact
@@ -768,7 +768,7 @@ void reparent_cmd(void){
   const char *zDateOvrd;  /* The change time on the control artifact */
   const char *zUserOvrd;  /* The user name on the control artifact */
 
-  if( find_option("dryrun","n",0)!=0 ) dryRun = TAG_ADD_DRYRUN;
+  if( find_option("dry-run","n",0)!=0 ) dryRun = TAG_ADD_DRYRUN;
   zDateOvrd = find_option("date-override",0,1);
   zUserOvrd = find_option("user-override",0,1);
   db_find_and_open_repository(0, 0);
