@@ -248,7 +248,7 @@ static void add_pax_header(
   /* build the string */
   blob_appendf(&tball.pax, "%d %s=%*.*s\n", blen, zField, nValue, nValue, zValue);
   /* this _must_ be right */
-  if(blob_size(&tball.pax) != blen){
+  if((int)blob_size(&tball.pax) != blen){
     fossil_panic("internal error: PAX tar header has bad length");
   }
 }
@@ -467,7 +467,7 @@ void test_tarball_cmd(void){
 **
 */
 void tarball_of_checkin(
-  int rid,             /* The RID of the checkin from which to form a tarball */
+  int rid,             /* The RID of the check-in from which to form a tarball*/
   Blob *pTar,          /* Write the tarball into this blob */
   const char *zDir,    /* Directory prefix for all file added to tarball */
   Glob *pInclude,      /* Only add files matching this pattern */
@@ -607,7 +607,7 @@ void tarball_of_checkin(
 **
 ** If OUTPUTFILE is an empty string or "/dev/null" then no tarball is
 ** actually generated.  This feature can be used in combination with
-** the --list option to get a list of the filename that would be in the
+** the --list option to get a list of the filenames that would be in the
 ** tarball had it actually been generated.  Note that --list shows only
 ** filenames.  "tar tzf" shows both filesnames and subdirectory names.
 **
@@ -678,7 +678,7 @@ void tarball_cmd(void){
 /*
 ** Check to see if the input string is of the form:
 **
-**        checkin-name/filename.ext
+**        check-in-name/filename.ext
 **
 ** In other words, check to see if the input contains a single '/'
 ** character that separates a valid check-in name from a filename.
@@ -758,7 +758,7 @@ void tarball_page(void){
 
   login_check_credentials();
   if( !g.perm.Zip ){ login_needed(g.anon.Zip); return; }
-  load_control();
+  fossil_nice_default();
   zName = fossil_strdup(PD("name",""));
   z = P("r");
   if( z==0 ) z = P("uuid");
