@@ -202,7 +202,7 @@ static int unversioned_sync_flags(unsigned syncFlags){
   if( find_option("verbose","v",0)!=0 ){
     syncFlags |= SYNC_UV_TRACE | SYNC_VERBOSE;
   }
-  if( find_option("dryrun","n",0)!=0 ){
+  if( find_option("dry-run","n",0)!=0 ){
     syncFlags |= SYNC_UV_DRYRUN | SYNC_UV_TRACE | SYNC_VERBOSE;
   }
   return syncFlags;
@@ -220,7 +220,7 @@ static int contains_whitespace(const char *zName){
 }
 
 /*
-** COMMAND: uv*
+** COMMAND: uv#
 ** COMMAND: unversioned
 **
 ** Usage: %fossil unversioned SUBCOMMAND ARGS...
@@ -252,8 +252,9 @@ static int contains_whitespace(const char *zName){
 **    export FILE OUTPUT     Write the content of FILE into OUTPUT on disk
 **
 **    list | ls              Show all unversioned files held in the local
-**                           repository. Options:
+**                           repository.
 **
+**                           Options:
 **                              --glob PATTERN   Show only files that match
 **                              --like PATTERN   Show only files that match
 **                              -l               Show additional details for
@@ -266,13 +267,14 @@ static int contains_whitespace(const char *zName){
 **
 **                           Options:
 **                              -v|--verbose     Extra diagnostic output
-**                              -n|--dryrun      Show what would have happened
+**                              -n|--dry-run     Show what would have happened
 **
 **    remove|rm|delete FILE ...
 **                           Remove unversioned files from the local repository.
 **                           Changes are not pushed to other repositories until
-**                           the next sync.  Options:
+**                           the next sync.
 **
+**                           Options:
 **                              --glob PATTERN   Remove files that match
 **                              --like PATTERN   Remove files that match
 **
@@ -283,12 +285,11 @@ static int contains_whitespace(const char *zName){
 **
 **                           Options:
 **                              -v|--verbose     Extra diagnostic output
-**                              -n|--dryrun      Show what would have happened
+**                              -n|--dry-run     Show what would have happened
 **
 **    touch FILE ...         Update the TIMESTAMP on all of the listed files
 **
 ** Options:
-**
 **   --mtime TIMESTAMP       Use TIMESTAMP instead of "now" for the "add",
 **                           "edit", "remove", and "touch" subcommands.
 **   -R|--repository REPO    Use FILE as the repository
