@@ -411,8 +411,8 @@ static void win32_http_request(void *pAppData){
   }
 
   /*
-  ** The repository name is only needed if there was no open checkout.  This
-  ** is designed to allow the open checkout for the interactive user to work
+  ** The repository name is only needed if there was no open check-out.  This
+  ** is designed to allow the open check-out for the interactive user to work
   ** with the local Fossil server started via the "ui" command.
   */
   zIp = SocketAddr_toString(&p->addr);
@@ -618,6 +618,10 @@ void win32_http_server(
     blob_appendf(&options, " --mainmenu ");
     blob_append_escaped_arg(&options, g.zMainMenuFile, 1);
   }
+  if( builtin_get_js_delivery_mode()!=0 /* JS_INLINE==0 may change? */ ){
+    blob_appendf(&options, " --jsmode ");
+    blob_append_escaped_arg(&options, builtin_get_js_delivery_mode_name(), 0);
+  }
 #if USE_SEE
   zSavedKey = db_get_saved_encryption_key();
   savedKeySize = db_get_saved_encryption_key_size();
@@ -929,7 +933,7 @@ static void win32_http_service_running(DualSocket *pS){
 
 /*
 ** Try to start the http server as a windows service. If we are running in
-** a interactive console session, this routine fails and returns a non zero
+** an interactive console session, this routine fails and returns a non zero
 ** integer value. When running as service, this routine does not return until
 ** the service is stopped. In this case, the return value is zero.
 */
@@ -1026,7 +1030,7 @@ int win32_http_service(
 **
 **              Specifies the name of the repository to be served.
 **              The repository option may be omitted if the working directory
-**              is within an open checkout.
+**              is within an open check-out.
 **              The REPOSITORY can be a directory (aka folder) that contains
 **              one or more repositories with names ending in ".fossil".
 **              In that case, the first element of the URL is used to select
