@@ -248,6 +248,7 @@ set SQLITE_OPTIONS {
   -DSQLITE_HAVE_ZLIB
   -DSQLITE_ENABLE_DBPAGE_VTAB
   -DSQLITE_TRUSTED_SCHEMA=0
+  -DHAVE_USLEEP
 }
 #lappend SQLITE_OPTIONS -DSQLITE_ENABLE_FTS3=1
 #lappend SQLITE_OPTIONS -DSQLITE_ENABLE_STAT4
@@ -437,9 +438,10 @@ PIKCHR_OPTIONS = <<<PIKCHR_OPTIONS>>>
 # Closely related is SQLITE3_ORIGIN, with the same numeric mapping plus
 # a value of 2 means that we are building a client-provided sqlite3.c.
 SQLITE3_OBJ.0 = $(OBJDIR)/sqlite3.o
-SQLITE3_OBJ.1 =
+SQLITE3_OBJ.1 = $(OBJDIR)/sqlite3-see.o
 # SQLITE3_OBJ.2 is set by the configure process
 SQLITE3_OBJ.  = $(SQLITE3_OBJ.0)
+SQLITE3_OBJ   = $(SQLITE3_OBJ.$(SQLITE3_ORIGIN))
 
 # The USE_LINENOISE variable may be undefined, set to 0, or set
 # to 1. If it is set to 0, then there is no need to build or link
@@ -537,7 +539,7 @@ foreach s [lsort $src] {
   writeln "\$(OBJDIR)/$s.h:\t\$(OBJDIR)/headers\n"
 }
 
-writeln "\$(OBJDIR)/sqlite3.o:\t\$(SQLITE3_SRC)"
+writeln "\$(SQLITE3_OBJ):\t\$(SQLITE3_SRC)"
 writeln "\t\$(XTCC) \$(SQLITE_OPTIONS) \$(SQLITE_CFLAGS) \$(SEE_FLAGS) \\"
 writeln "\t\t-c \$(SQLITE3_SRC) -o \$@"
 
@@ -736,8 +738,8 @@ endif
 #
 ifndef X64
 SSLCONFIG = mingw
-ZLIBCONFIG = LOC="-DASMV -DASMINF" OBJA="inffas86.o match.o"
-ZLIBTARGETS = $(ZLIBDIR)/inffas86.o $(ZLIBDIR)/match.o
+ZLIBCONFIG =
+ZLIBTARGETS =
 else
 SSLCONFIG = mingw64
 ZLIBCONFIG =
@@ -1127,9 +1129,10 @@ $(OBJDIR)/phony.h:
 # plus a value of 2 means that we are building a client-provided
 # sqlite3.c.
 SQLITE3_OBJ.0 = $(OBJDIR)/sqlite3.o
-SQLITE3_OBJ.1 =
+SQLITE3_OBJ.1 = $(OBJDIR)/sqlite3-see.o
 # SQLITE3_OBJ.2 is set by the configure process
 SQLITE3_OBJ.  = $(SQLITE3_OBJ.0)
+SQLITE3_OBJ   = $(SQLITE3_OBJ.$(SQLITE3_ORIGIN))
 
 # The USE_SEE variable may be undefined, 0 or 1.  If undefined or 0,
 # in-tree SQLite is used.  If 1, then sqlite3-see.c (not part of the
@@ -1163,12 +1166,6 @@ EXTRAOBJ = <<<NEXT_LINE>>>
 }]
 
 writeln {
-$(ZLIBDIR)/inffas86.o:
-	$(TCC) -c -o $@ -DASMINF -I$(ZLIBDIR) -O3 $(ZLIBDIR)/contrib/inflate86/inffas86.c
-
-$(ZLIBDIR)/match.o:
-	$(TCC) -c -o $@ -DASMV $(ZLIBDIR)/contrib/asm686/match.S
-
 zlib:	$(ZLIBTARGETS)
 	$(MAKE) -C $(ZLIBDIR) PREFIX=$(PREFIX) CC=$(PREFIX)$(TCCEXE) $(ZLIBCONFIG) -f win32/Makefile.gcc libz.a
 
@@ -1279,7 +1276,7 @@ writeln "SQLITE_OPTIONS = [join $MINGW_SQLITE_OPTIONS $j]\n"
 writeln "SHELL_OPTIONS = [join $SHELL_WIN32_OPTIONS $j]\n"
 writeln "PIKCHR_OPTIONS = [join $MINGW_PIKCHR_OPTIONS $j]\n"
 
-writeln "\$(OBJDIR)/sqlite3.o:\t\$(SQLITE3_SRC) \$(SRCDIR)/../win/Makefile.mingw"
+writeln "\$(SQLITE3_OBJ):\t\$(SQLITE3_SRC) \$(SRCDIR)/../win/Makefile.mingw"
 writeln "\t\$(XTCC) \$(SQLITE_OPTIONS) \$(SQLITE_CFLAGS) \$(SEE_FLAGS) \\"
 writeln "\t\t-c \$(SQLITE3_SRC) -o \$@\n"
 
