@@ -40,6 +40,7 @@ set doclist {
   copyright-release.html {Contributor License Agreement}
   concepts.wiki {Fossil Core Concepts}
   contact.md {Developer Contact Information}
+  containers.md {OCI Containers}
   contribute.wiki {Contributing Code or Documentation To The Fossil Project}
   css-tricks.md {Fossil CSS Tips and Tricks}
   customgraph.md {Theming: Customizing the Timeline Graph}
@@ -169,8 +170,11 @@ puts $out {
 <li> <a href='../COPYRIGHT-BSD2.txt'>License</a>
 <li> <a href='userlinks.wiki'>Miscellaneous Docs for Fossil Users</a>
 <li> <a href='hacker-howto.wiki'>Fossil Developer's Guide</a>
+  <ul><li><a href='$ROOT/wiki?name=Release Build How-To'>Release Build How-To</a>, a.k.a.
+  how deliverables are built</li></ul>
+</li>
 <li> <a href='$ROOT/wiki?name=To+Do+List'>To Do List (Wiki)</a>
-<li> <a href='http://fossil-scm.org/fossil-book/home'>Fossil book</a>
+<li> <a href='https://fossil-scm.org/fossil-book/'>Fossil book</a>
 </ul>
 <h2 id="pindex">Other Documents:</h2>
 <ul>}
